@@ -1,7 +1,7 @@
 import torch
 import torch.nn as nn
 
-import ops
+from . import ops
 from . import decoders
 from . import encoders
 
